@@ -25,6 +25,7 @@ class HTTP4Store(object):
         self.sparql_endpoint = "%ssparql/" % http_endpoint
         self.data_endpoint = "%sdata/" % http_endpoint
         self.status_endpoint = "%sstatus/" % http_endpoint
+        self.size_endpoint = "%sstatus/size/" % http_endpoint
         self.rh = RequestHandler()
         self.sh = SparqlResponseHandler()
 
@@ -44,6 +45,21 @@ class HTTP4Store(object):
         status['kb'] = body.find('h2').text[3:]
         return status
     
+# on hiatus for now... til the size page gets cleaned up
+#    def size(self):
+#        robj = self.rh.GET(self.size_endpoint)
+#        assert robj.status == 200
+#        sizes = []
+#        # Chop off the crud at the top
+#        fixed = robj.content.split('\n', 1)[-1].split('\n')
+#        fixed.insert(-2, '</table>')
+#        doc = ET.fromstring("".join(fixed))
+#        body = doc.find('body')
+#        for row in body.find('table').findall('tr'):
+#            row_cells = row.getchildren()
+#            if row_cells.
+#        return sizes
+    
     def sparql(self, query_string, accept="text/tab-separated-values", headers={}, get_raw_response_obj=False):
         if accept:
             headers['Accept'] = accept
@@ -74,7 +90,7 @@ class HTTP4Store(object):
         
         # TODO - if content is a graph -> serialised form for posting
         
-        return self.rh.PUT("%s%s" % (self.sparql_endpoint, uri), 
+        return self.rh.PUT("%s%s" % (self.data_endpoint, uri), 
                                headers=headers, 
                                body=content)
     
@@ -97,7 +113,6 @@ class HTTP4Store(object):
         params['graph'] = uri
         params['data'] = content
         params['mime-type'] = mapping_type.get(content_type, 'application/x-turtle')
-	
         headers = {}
         headers['content-type'] = 'application/x-www-form-urlencoded'
       
