@@ -2,4 +2,4 @@ from HTTP4Store import HTTP4Store
 
 from sparql_response import SparqlResponseHandler
 
-from utils import RequestHandler
+from utils import RequestHandler, HTTP4StoreConnectionException
